Learn R Programming

readmet (version 1.7.1)

dmna.axes: read grid positions from a file in DMNA-format

Description

Files in DMNA format contain gridded data. The header provides information on how the data are organized. This routine expands the positions of the grid planes along each dimension used in the file. The values are put out in columns x, y, z for each respective axis.

Usage

dmna.axes(file, debug = FALSE)

Value

returns a data.frame with the following columns:

x

grid positions along the x axis

y

grid positions along the y axis

z

grid level heights

Arguments

file

name (and path if necessary) of the file to read

debug

if TRUE shwon debugging information

Author

Clemens Druee

References

AUSTAL 3.1 model reference (by Ingenieurbuero Janicke)

Examples

Run this code
ax <- dmna.axes(system.file("extdata", "example-grid.dmna", package="readmet"))
ax$x

Run the code above in your browser using DataLab