Learn R Programming

readmet (version 1.7.1)

dmna.header: read header information from a file in DMNA-format

Description

Files in DMNA format contain gridded data. The header provides information on how the data are organized and other user-specified meta data. DMNA is used for example by the German national dispersion model AUSTAL2000.

Usage

dmna.header(file)

Value

list(character)

Arguments

file

name (and path if necessary) of the file to read

Author

Clemens Druee

References

AUSTAL2000 model reference (by Ingenieurbuero Janicke)

Examples

Run this code
hdr <- dmna.header(system.file("extdata", "example-grid.dmna", package="readmet"))
hdr$idnt

Run the code above in your browser using DataLab