Learn R Programming

readmet (version 1.7.1)

read.scintec1: function to read the contents of a file in Scintec Format-1

Description

reads output data (extension ".mnd") from Scintec atmospheric measurement systems into a list that contains the variable names as names and the values as either matrix or vector.

Usage

read.scintec1(files)

Value

list(different types)

vector

lenght = n (number of times contained in the file)
each vevtor contains a non-profile variable (see variable list)
special varaible name "time" contains the times as POSIXct

matrix

dim(n,m) where n is number of times contained in the file and m is the number of levels
i.e. rows represents timeseries of at a fixed level, columns represent profiles at a fixed time

Arguments

files

array containing names (and path if necessary) of the files to read

Author

Clemens Druee

References

Scintec APRun software manual

Examples

Run this code
mnd <- read.scintec1(system.file("extdata", "example.mnd", package="readmet"))
mnd$CT2

Run the code above in your browser using DataLab