Learn R Programming

readmet (version 1.7.1)

scintec1.header: read the header of a file in Scintec Format-1 format

Description

get timeseries of non-profile variables from a a Scintec atmospheric profiler data format "Format-1" (extension ".mnd")

Usage

scintec1.header(file)

Value

named list; each entry corresponds to one header field:

starttime

starting time of the measurement as POSIXct object

filecount

running number of files produced during the current measurement

instrument

model type of the device

commentlines

lines of text containing the coment list

variables

lines of text containing the list of the variables in encoded form

heightlevels

number of height of levels where data are produced

Arguments

file

name (and path if necessary) of the file to read

Author

Clemens Druee

References

Scintec APRun software manual

Examples

Run this code
hdr <- read.scintec1(system.file("extdata", "example.mnd", package="readmet"))
hdr$instrument

Run the code above in your browser using DataLab