Learn R Programming

readmet (version 1.7.1)

scintec1.nonprofile: read the single-level variables from a file in Scintec Format-1 format

Description

get timeseries of non-profile variables from a a Scintec atmospheric profiler data format "Format-1" (extension ".mnd")

Usage

scintec1.nonprofile(file, header = list(), vars = list())

Value

list(vector); length(vector) = n (number of times contained in the file)

each vevtor contains a non-profile variable (see variable list) special varaible name "time" contains the times as POSIXct

Arguments

file

name (and path if necessary) of the file to read

header

optionally, instead of reading the header from the file again, the output of a previous call to scintec1.header on the same file can be supplied via this argument.

vars

optionally, instead of reading the header from the file again, the output of a previous call to scintec1.variables on the same file can be supplied via this argument.

Author

Clemens Druee

References

Scintec APRun software manual

Examples

Run this code
dat <- scintec1.nonprofile(system.file("extdata", "example.mnd", package="readmet"))
head(dat)

Run the code above in your browser using DataLab