Learn R Programming

readmet (version 1.7.1)

scintec1.profile: read the multi-level (profile) variables from a Scintec Format-1 file

Description

get profile variables from a Scintec atmospheric profiler data format "Format-1" (extension ".mnd")

Usage

scintec1.profile(file, header = list(), vars = list())

Value

list(matrix); dim(matrix)=c(n,m)

where n is number of times contained in the file and m is the number of levels

i.e. rows represents timeseries of at a fixed level, columns represent profiles at a fixed time

Arguments

file

name (and path if necessary) of the file to read

header

optionally, instead of reading the header from the file again, the output of a previous call to scintec1.header on the same file can be supplied via this argument.

vars

optionally, instead of reading the header from the file again, the output of a previous call to scintec1.variables on the same file can be supplied via this argument.

Author

Clemens Druee

References

Scintec APRun software manual

Examples

Run this code
dat <- scintec1.profile(system.file("extdata", "example.mnd", package="readmet"))
dat

Run the code above in your browser using DataLab