powered by
get timeseries of non-profile variables from a a Scintec atmospheric profiler data format "Format-1" (extension ".mnd")
scintec1.header(file)
named list; each entry corresponds to one header field:
starting time of the measurement as POSIXct object
running number of files produced during the current measurement
model type of the device
lines of text containing the coment list
lines of text containing the list of the variables in encoded form
number of height of levels where data are produced
name (and path if necessary) of the file to read
Clemens Druee
Scintec APRun software manual
hdr <- read.scintec1(system.file("extdata", "example.mnd", package="readmet")) hdr$instrument
Run the code above in your browser using DataLab